#!/bin/sh -e
LOGGER="logger -p local1.notice"

jsonval() {
	sed -e 's!\([^\\]\)"!\1!g' -e 's!,$!!' $1 | \
	sed -n "s!.*${2}: *\(.*\)!\1!p"
}

# Move to configuration directory
cd /mnt/fsuser-1/spf/etc

# Lock on pid file
exec 8> /var/run/packet_forwarder.pid
flock -n -x 8
trap "rm -f /var/run/packet_forwarder.pid" EXIT

# Create configuration and version files
ln -fs /mnt/fsuser-1/spf/etc/global_conf.json /tmp/packet_forwarder.conf
echo spf 3.1.0-klk11 +hal_libloragw_4.1.3-klk3 > /tmp/packet_forwarder_version.txt

# Restart modem
[ -z "$(which modem_off.sh)" ] || modem_off.sh
[ -z "$(which modem_on.sh)" ] || modem_on.sh | $LOGGER -t modem

# Open firewall ports
iptables_accept() {
	local PORT=$(jsonval $@)
	[ -z "${PORT}" ] && return
	local RULE="OUTPUT -t filter -p udp --dport $PORT -j ACCEPT"
	iptables -C $RULE 2> /dev/null || iptables -A $RULE
	local RULE="INPUT -t filter -p udp --sport $PORT -j ACCEPT"
	iptables -C $RULE 2> /dev/null || iptables -A $RULE
}

iptables_accept /tmp/packet_forwarder.conf serv_port_up
iptables_accept /tmp/packet_forwarder.conf serv_port_down

# Wait until lns is available
LNS=$(jsonval /tmp/packet_forwarder.conf server_address)
[ -z "${LNS}" ] && echo "Failed to get lns address" | $LOGGER && exit 1
trap "exit" INT QUIT TERM
while ! nslookup $LNS > /dev/null 2>&1 ; do
	echo "Waiting until lns '${LNS}' is available" | $LOGGER
	sleep 10
done

# Start packet forwarder
/mnt/fsuser-1/spf/bin/spf 2>&1 | $LOGGER -t spf &
trap "killall -q spf" INT QUIT TERM

# Update pid and wait for it
pidof spf >&8
wait
